==> nextcloud-23.0.3.tgz: nextcloud/apps/dav/l10n/uk.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "До роботи",
    "Personal" : "Особисте",
    "{actor} created calendar {calendar}" : "{actor} створив календар {calendar}",
    "You created calendar {calendar}" : "Ви створили календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} вилучив календар {calendar}",
    "You deleted calendar {calendar}" : "Ви вилучили календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} оновив календар {calendar}",
    "You updated calendar {calendar}" : "Ви оновили календар {calendar}",
    "You shared calendar {calendar} as public link" : "Ви поширили календар {calendar} як публічне посилання",
    "You removed public link for calendar {calendar}" : "Ви вилучили публічне посилання на календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} поширив календар {calendar} з вами",
    "You shared calendar {calendar} with {user}" : "Ви поширили календар {calendar} з {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} поширив календар {calendar} з {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} припинив поширення календаря {calendar} з вами",
    "You unshared calendar {calendar} from {user}" : "Ви припинили поширення календаря {calendar} з {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} припинив поширення календаря {calendar} з {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} припинив поширення календаря {calendar} між собою",
    "You shared calendar {calendar} with group {group}" : "Ви поширили календар {calendar} з групою {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} поширив календар {calendar} з групою {group}",
    "You unshared calendar {calendar} from group {group}" : "Ви припинили поширення календаря {calendar} з групою {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} припинив поширення календаря {calendar} з групою {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} створив подію {event} у календарі {calendar}",
    "You created event {event} in calendar {calendar}" : "Ви створили подію {event} у календарі {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} вилучив подію {event} з календаря {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Ви вилучили подію {event} з календаря {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} оновив подію {event} у календарі {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ви оновили подію {event} у календарі {calendar}",
    "Busy" : "Зайнято",
    "{actor} created todo {todo} in list {calendar}" : "{actor} створив завдання {todo} у списку {calendar}",
    "You created todo {todo} in list {calendar}" : "Ви створили завдання {todo} у списку {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} вилучили завдання {todo} зі списку {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ви вилучили завдання {todo} зі списку {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} оновив завдання {todo} у списку {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ви оновили завдання {todo} у списку {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} виконав завдання {todo} зі списку {calendar}",
    "You solved todo {todo} in list {calendar}" : "Ви виконали завдання {todo} зі списку {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} повторно відкрив завдання {todo} у списку {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Ви повторно відкрили завдання {todo} у списку {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> був змінений",
    "A calendar <strong>event</strong> was modified" : "Календарна <strong>подія</strong> була змінена",
    "A calendar <strong>todo</strong> was modified" : "Календарне <strong>завдання</strong> було змінене",
    "Contact birthdays" : "Дні народження контактів",
    "Death of %s" : "Смерть %s",
    "Calendar:" : "Календар:",
    "Date:" : "Дата:",
    "Where:" : "Місце:",
    "Description:" : "Опис:",
    "Untitled event" : "Подія без назви",
    "_%n year_::_%n years_" : ["%n рік","%n років","%n років","%n роки "],
    "_%n month_::_%n months_" : ["%n місяць","%n місяців","%n місяців","%n місяці"],
    "_%n day_::_%n days_" : ["%n день","%n днів","%n днів","%n дні"],
    "_%n hour_::_%n hours_" : ["%n година","%n години","%n годин","%n години"],
    "_%n minute_::_%n minutes_" : ["%n хвилина","%n хвилин","%n хвилин","%n хвилини"],
    "%s (in %s)" : "%s (у %s)",
    "%s (%s ago)" : "%s (%s тому)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Дата: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Місце: %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Invitation canceled" : "Запрошення скасоване",
    "Invitation updated" : "Запрошення оновлене",
    "Location:" : "Місцевість:",
    "Link:" : "Посилання:",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "More options …" : "Більше варіантів …",
    "More options at %s" : "Більше варіантів на %s",
    "Contacts" : "Контакти",
    "Upgrade needed" : "Потрібно оновитися",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ваш %s мусить бути налаштований на використання HTTPS для надання доступу до CalDAV і CardDAV з iOS/macOS.",
    "Configures a CalDAV account" : "Налаштовує обліковий запис CalDAV",
    "Configures a CardDAV account" : "Налаштовує обліковий запис CardDAV",
    "Tasks" : "Завдання",
    "Untitled task" : "Завдання без назви",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Точка доступу WebDAV",
    "Save" : "Зберегти",
    "Calendar server" : "Сервер календаря",
    "Send invitations to attendees" : "Надіслати запрошення учасникам",
    "Automatically generate a birthday calendar" : "Автоматично згенерувати календар днів народження",
    "Birthday calendars will be generated by a background job." : "Календар днів народження буде згенеровано у фоновому завданні.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Отже вони не будуть доступні одразу після увімкнення, але з'являться згодом.",
    "Send notifications for events" : "Відправити сповіщення для подій",
    "Notifications are sent via background jobs, so these must occur often enough." : "Сповіщення надсилаються у фонових завданнях, тож вони мають запускатися достатньо часто.",
    "Enable notifications for events via push" : "Увімкнути push-сповіщення для подій",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Встановіть також {calendarappstoreopen}застосунок Календар{linkclose}, або {calendardocopen}з'єднайте ваш декстоп і мобільний для синхронізації ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Будь-ласка переконайтеся у коректності налаштувань {emailopen}поштового сервера{linkclose}.",
    "There was an error updating your attendance status." : "Виникла помилка при оновленні вашого статусу учасника.",
    "Please contact the organizer directly." : "Будь-ласка повідомте організатора.",
    "Are you accepting the invitation?" : "Чи приймаєте ви запрошення?",
    "Tentative" : "Попередній",
    "Your attendance was updated successfully." : "Ваша участь успішно оновлена."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/dav/l10n/uk.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Personal" : "Особисте",
    "{actor} created calendar {calendar}" : "{actor} створив календар {calendar}",
    "You created calendar {calendar}" : "Ви створили календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} вилучив календар {calendar}",
    "You deleted calendar {calendar}" : "Ви вилучили календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} оновив календар {calendar}",
    "You updated calendar {calendar}" : "Ви оновили календар {calendar}",
    "You shared calendar {calendar} as public link" : "Ви поширили календар {calendar} як публічне посилання",
    "You removed public link for calendar {calendar}" : "Ви вилучили публічне посилання на календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} поширив календар {calendar} з вами",
    "You shared calendar {calendar} with {user}" : "Ви поширили календар {calendar} з {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} поширив календар {calendar} з {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} припинив поширення календаря {calendar} з вами",
    "You unshared calendar {calendar} from {user}" : "Ви припинили поширення календаря {calendar} з {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} припинив поширення календаря {calendar} з {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} припинив поширення календаря {calendar} між собою",
    "You shared calendar {calendar} with group {group}" : "Ви поширили календар {calendar} з групою {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} поширив календар {calendar} з групою {group}",
    "You unshared calendar {calendar} from group {group}" : "Ви припинили поширення календаря {calendar} з групою {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} припинив поширення календаря {calendar} з групою {group}",
    "Untitled event" : "Подія без назви",
    "{actor} created event {event} in calendar {calendar}" : "{actor} створив подію {event} у календарі {calendar}",
    "You created event {event} in calendar {calendar}" : "Ви створили подію {event} у календарі {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} вилучив подію {event} з календаря {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Ви вилучили подію {event} з календаря {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} оновив подію {event} у календарі {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ви оновили подію {event} у календарі {calendar}",
    "Busy" : "Зайнято",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> був змінений",
    "A calendar <strong>event</strong> was modified" : "Календарна <strong>подія</strong> була змінена",
    "Contact birthdays" : "Дні народження контактів",
    "Death of %s" : "Смерть %s",
    "Calendar:" : "Календар:",
    "Date:" : "Дата:",
    "Where:" : "Місце:",
    "Description:" : "Опис:",
    "_%n year_::_%n years_" : ["%n рік","%n років","%n років","%n роки "],
    "_%n month_::_%n months_" : ["%n місяць","%n місяців","%n місяців","%n місяці"],
    "_%n day_::_%n days_" : ["%n день","%n днів","%n днів","%n дні"],
    "_%n hour_::_%n hours_" : ["%n година","%n години","%n годин","%n години"],
    "_%n minute_::_%n minutes_" : ["%n хвилина","%n хвилин","%n хвилин","%n хвилини"],
    "%s (in %s)" : "%s (у %s)",
    "%s (%s ago)" : "%s (%s тому)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Дата: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Місце: %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Invitation canceled" : "Запрошення скасоване",
    "Invitation updated" : "Запрошення оновлене",
    "Location:" : "Місцевість:",
    "Link:" : "Посилання:",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "More options …" : "Більше варіантів …",
    "More options at %s" : "Більше варіантів на %s",
    "Contacts" : "Контакти",
    "Upgrade needed" : "Потрібно оновитися",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ваш %s мусить бути налаштований на використання HTTPS для надання доступу до CalDAV і CardDAV з iOS/macOS.",
    "Configures a CalDAV account" : "Налаштовує обліковий запис CalDAV",
    "Configures a CardDAV account" : "Налаштовує обліковий запис CardDAV",
    "Tasks" : "Завдання",
    "Untitled task" : "Завдання без назви",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Точка доступу WebDAV",
    "to" : "до",
    "Monday" : "понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sunday" : "Неділя",
    "Save" : "Зберегти",
    "Calendar server" : "Сервер календаря",
    "Send invitations to attendees" : "Надіслати запрошення учасникам",
    "Automatically generate a birthday calendar" : "Автоматично згенерувати календар днів народження",
    "Birthday calendars will be generated by a background job." : "Календар днів народження буде згенеровано у фоновому завданні.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Отже вони не будуть доступні одразу після увімкнення, але з'являться згодом.",
    "Send notifications for events" : "Відправити сповіщення для подій",
    "Notifications are sent via background jobs, so these must occur often enough." : "Сповіщення надсилаються у фонових завданнях, тож вони мають запускатися достатньо часто.",
    "Enable notifications for events via push" : "Увімкнути push-сповіщення для подій",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Встановіть також {calendarappstoreopen}застосунок Календар{linkclose}, або {calendardocopen}з'єднайте ваш декстоп і мобільний для синхронізації ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Будь-ласка переконайтеся у коректності налаштувань {emailopen}поштового сервера{linkclose}.",
    "There was an error updating your attendance status." : "Виникла помилка при оновленні вашого статусу учасника.",
    "Please contact the organizer directly." : "Будь-ласка повідомте організатора.",
    "Are you accepting the invitation?" : "Чи приймаєте ви запрошення?",
    "Tentative" : "Попередній",
    "Comment" : "Коментар",
    "Your attendance was updated successfully." : "Ваша участь успішно оновлена.",
    "Todos" : "До роботи",
    "{actor} created todo {todo} in list {calendar}" : "{actor} створив завдання {todo} у списку {calendar}",
    "You created todo {todo} in list {calendar}" : "Ви створили завдання {todo} у списку {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} вилучили завдання {todo} зі списку {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ви вилучили завдання {todo} зі списку {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} оновив завдання {todo} у списку {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ви оновили завдання {todo} у списку {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} виконав завдання {todo} зі списку {calendar}",
    "You solved todo {todo} in list {calendar}" : "Ви виконали завдання {todo} зі списку {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} повторно відкрив завдання {todo} у списку {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Ви повторно відкрили завдання {todo} у списку {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Календарне <strong>завдання</strong> було змінене"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
